# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, Annotated, TypedDict

from ...._utils import PropertyInfo

__all__ = ["AndroidUninstallParams"]


class AndroidUninstallParams(TypedDict, total=False):
    box_id: Required[Annotated[str, PropertyInfo(alias="boxId")]]

    keep_data: Annotated[bool, PropertyInfo(alias="keepData")]
    """uninstalls the pkg while retaining the data/cache"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

from ...._types import FileTypes

__all__ = ["AndroidRestoreParams"]


class AndroidRestoreParams(TypedDict, total=False):
    backup: Required[FileTypes]
    """Backup file to restore (max file size: 100MB)"""



from gbox_sdk._client import GboxClient
from gbox_sdk.wrapper.box.base import BaseBox
from gbox_sdk.types.v1.linux_box import LinuxBox


class LinuxBoxOperator(BaseBox):
    """
    Operator class for managing Linux boxes via the Gbox SDK.
    Provides an interface to interact with and control Linux-based boxes.
    """

    def __init__(self, client: GboxClient, data: LinuxBox):
        """
        Initialize a LinuxBoxOperator instance.

        Args:
            client (GboxClient): The Gbox client used for API communication.
            data (LinuxBox): The LinuxBox data model instance representing the box.
        """
        super().__init__(client, data)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Union
from typing_extensions import TypeAlias, TypedDict

from .action_screenshot_options_param import ActionScreenshotOptionsParam

__all__ = ["ActionCommonOptionsParam", "Screenshot"]

Screenshot: TypeAlias = Union[ActionScreenshotOptionsParam, bool]


class ActionCommonOptionsParam(TypedDict, total=False):
    screenshot: Screenshot
    """Screenshot options.

    Can be a boolean to enable/disable screenshots, or an object to configure
    screenshot options.
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from datetime import datetime

from pydantic import Field as FieldInfo

from ...._models import BaseModel

__all__ = ["MediaAlbum"]


class MediaAlbum(BaseModel):
    last_modified: datetime = FieldInfo(alias="lastModified")
    """Last modified time of the album"""

    media_count: float = FieldInfo(alias="mediaCount")
    """Number of media files in the album"""

    name: str
    """Name of the album"""

    path: str
    """Full path to the album in the box"""
